function [busNames,Buses] = SCDalgo_template_signal_buses()
% [busNames,Buses] = SCDalgo_template_signal_buses()
% Define some buses needed for the template

%% Define signal buses for various SCDsignal types
% Data examples for which to create buses
D = {...
  ones(11,1,'single'),...
  ones(3,3,'double'),...
  int32(1)};

% Create buses for these signals and add them to the list
[Buses,busNames] = deal(cell(numel(D),1)); % init
for ii = 1:numel(D)
  mydata = D{ii};
  mysig = SCDsignal(mydata); % create SCDsignal object for this data example
  mybus = mysig.createBus; % create Bus for this signal using object method
  % Store
  Buses{ii} = mybus;
  busNames{ii} = mybus.Description;
end

%% Add output structure: a bus that includes both numeric and SCDsignal types

% First add 3 busElements for the three signals defined above
for ii=1:3
elems(ii) = Simulink.BusElement;
elems(ii).Name = sprintf('SCDsignal_example_%d',ii);
elems(ii).Dimensions = 1;
elems(ii).DimensionsMode = 'Fixed';
elems(ii).DataType = sprintf('Bus: %s',busNames{ii});
end
% add a numeric data type
ii=ii+1; 
elems(ii) = Simulink.BusElement;
elems(ii).Name = 'single_scalar';
elems(ii).Dimensions = 1;
elems(ii).DimensionsMode = 'Fixed';
elems(ii).DataType = 'single';

% Define output bus with these elements
outBus = Simulink.Bus;
outBus.HeaderFile = '';
outBus.Description = '';
outBus.DataScope = 'Auto';
outBus.Alignment = -1;
outBus.Elements = elems;
clear elems;

% append to list
busNames{end+1} = 'SCDalgo_template_outBus'
Buses{end+1}    = outBus; 

end